@@ -34,3 +34,6 @@ def sample_execute_function_to_test_cleanup(params):
     was_environment_clean = 1 if not _is_environment_dirty() else 0
     _make_environment_dirty()
     return {'sum': params['x'] + params['y'], 'just_x': params['x'], 'was_environment_clean': was_environment_clean}
+
+def sample_manual_func(*args, **kwargs):
+    return (list(args), kwargs)
